fermi_velocity_mesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# fermi_velocity_mesh

property ElectronicBandStructure.fermi_velocity_mesh

  Fermi Velocity mesh is a numpy array that stores each Fermi Velocity in a mesh grid. Shape = [n_bands,n_kx,n_ky,n_kz,3], where the first dimension represents d/dx,d/dy,d/dz

  Returns:

    np.ndarray – Fermi Velocity mesh is a numpy array that stores each Fermi Velocity in a mesh grid. Shape = [n_bands,n_kx,n_ky,n_kz,3], where the first dimension represents d/dx,d/dy,d/dz